==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/plugins/coreplugin/statusbarmanager.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef STATUSBARMANAGER_H
#define STATUSBARMANAGER_H

#include "minisplitter.h"

#include <QList>
#include <QObject>

QT_BEGIN_NAMESPACE
class QWidget;
QT_END_NAMESPACE

namespace Core {
namespace Internal {

class MainWindow;

class NonResizingSplitter : public MiniSplitter
{
    Q_OBJECT

public:
    explicit NonResizingSplitter(QWidget *parent);

protected:
    void resizeEvent(QResizeEvent *ev);
};

class StatusBarManager : public QObject
{
    Q_OBJECT

public:
    StatusBarManager(MainWindow *mainWnd);
    ~StatusBarManager();

    void init();
    void extensionsInitalized();
    void restoreSettings();

private:
    void objectAdded(QObject *obj);
    void aboutToRemoveObject(QObject *obj);
    void saveSettings();

    MainWindow *m_mainWnd;
    QSplitter *m_splitter;
    QList<QWidget *> m_statusBarWidgets;
};

} // namespace Internal
} // namespace Core

#endif // STATUSBARMANAGER_H

==> qt-creator-opensource-src-4.5.1.zip: qt-creator-opensource-src-4.5.1/src/plugins/coreplugin/statusbarmanager.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QList>
#include <QObject>

QT_BEGIN_NAMESPACE
class QSplitter;
class QWidget;
QT_END_NAMESPACE

namespace Core {
namespace Internal {

class MainWindow;

class StatusBarManager : public QObject
{
    Q_OBJECT

public:
    StatusBarManager(MainWindow *mainWnd);
    ~StatusBarManager();

    void init();
    void extensionsInitalized();
    void restoreSettings();

private:
    void objectAdded(QObject *obj);
    void aboutToRemoveObject(QObject *obj);
    void saveSettings();

    MainWindow *m_mainWnd;
    QSplitter *m_splitter;
    QList<QWidget *> m_statusBarWidgets;
};

} // namespace Internal
} // namespace Core
